# Originally imported from rosa
# Extras from https://launchpad.net/~brandonsnider/+archive/ubuntu/cdrtools

%define orig 3.02
%define debug_package %{nil}

Name: 		cdrtools
Version: 	3.02a09
Release: 	%mkrel 1
Summary: 	Tools for working with writable CD, DVD and BluRay media
Url: 		http://cdrtools.sourceforge.net/private/cdrecord.html
License: 	Various Open Source Licenses (CDDL.Schily, GPL-2.0, LGPL-2.1, BSD)
Source0: 	https://sourceforge.net/projects/cdrtools/files/alpha/%{name}-%{version}.tar.xz
Source1: 	cdrtools_3.02a07-debian.tar.xz
Group: 		Archiving/Cd burning
BuildRequires: 	smake fdupes
BuildRequires: 	libcap-devel
BuildRequires: 	pkgconfig(alsa)
BuildRequires: 	pkgconfig(libpulse)
Provides: 	cdrecord = %{version}-%{release}
Provides: 	mkisofs = %{version}-%{release}
Provides: 	cdda2wav = %{version}-%{release}
Requires: 	libcap-utils

%description
Cdrtools is a set of command line programs that allows to record CD/DVD/BluRay media.

The suite includes the following programs:

  cdrecord  A CD/DVD/BD recording program 
  readcd    A program to read CD/DVD/BD media with CD-clone features 
  cdda2wav  The most evolved CD-audio extraction program with paranoia support 
  mkisofs   A program to create hybrid ISO-9660/Joliet/HFS filesystems
            with optional Rock Ridge attributes 
  isodebug  A program to print mkisofs debug information from media 
  isodump   A program to dump ISO-9660 media 
  isoinfo   A program to analyse/verify ISO-9660/Joliet/Rock-Ridge filesystems 
  isovfy    A program to verify the ISO-9660 structures 
  rscsi     A Remote SCSI enabling daemon 

These are installed at /usr/local so as not to conflict with the cdrkit binaries.

%prep
%setup -qn %{name}-%{orig}

sed -i -e 's,^INS_BASE=.*,INS_BASE=%{_prefix}/local,g' DEFAULTS/*
sed -i -e 's,-noclobber,,' cdrecord/Makefile.dfl

# Remove lib*/*_p.mk to skip the compilation of profiled libs
rm -f lib*/*_p.mk

# extract additional stuff
pushd $RPM_BUILD_DIR/%{name}-%{orig}
tar -xJf %SOURCE1
popd

%build
smake

%install
smake DESTDIR=%{buildroot} install

# Set suid for cdrecord as we see in cdrtools PPA
chmod 4755 %{buildroot}%{_prefix}/local/bin/cdrecord

# Not much of a point in shipping static libs and headers
rm -rf %{buildroot}%{_prefix}/local/lib/*.a \
	%{buildroot}%{_prefix}/local/include

# Install the scripts for wodim, readom and genisoimage
install -m 0755 debian/wodim %{buildroot}%{_prefix}/local/bin/wodim
install -m 0755 debian/readom %{buildroot}%{_prefix}/local/bin/readom
install -m 0755 debian/genisoimage %{buildroot}%{_prefix}/local/bin/genisoimage

# Install additional programs
install -m 0755 cdda2wav/{cdda2mp3.new,inf2cdtext.pl,pitchplay,readmult,tracknames.pl} \
	mkisofs/hdisk.pl %{buildroot}%{_prefix}/local/bin

# Fix perl path
perl -pi -e 's#/usr/local/bin/perl#%_bindir/perl#g' %{buildroot}%{_prefix}/local/bin/tracknames.pl

# Create link for dvdrecord
pushd %{buildroot}%{_prefix}/local/bin
ln -s cdrecord dvdrecord
# Needed by cdda2wav (see cdda2wav.c)
ln -s cdda2wav list_audio_tracks
popd

# We may remove these
rm -rf %{buildroot}%{_prefix}/local/share/man/man3/* \
	%{buildroot}%{_prefix}/local/share/man/man5/*

find %{buildroot}%{_prefix}/local/share/man -type f -exec gzip -9 {} \;

fdupes -s %{buildroot}%{_prefix}/local

%clean
rm -rf %{buildroot}

%post
%{_sbindir}/setcap cap_sys_resource,cap_dac_override,cap_sys_admin,cap_sys_nice,cap_net_bind_service,cap_ipc_lock,cap_sys_rawio+ep /usr/local/bin/cdrecord
%{_sbindir}/setcap cap_dac_override,cap_sys_admin,cap_sys_nice,cap_net_bind_service,cap_sys_rawio+ep /usr/local/bin/cdda2wav
%{_sbindir}/setcap cap_dac_override,cap_sys_admin,cap_net_bind_service,cap_sys_rawio+ep /usr/local/bin/readcd

%pre
update-alternatives --remove cdrecord %{_bindir}/wodim
update-alternatives --remove cdrecord %{_bindir}/cdrskin
update-alternatives --remove mkisofs %{_bindir}/genisoimage
update-alternatives --remove mkhybrid %{_bindir}/genisoimage
update-alternatives --remove mkisofs %{_bindir}/xorriso
update-alternatives --remove cdda2wav %{_bindir}/icedax
update-alternatives --remove readcd %{_bindir}/readom

%preun
update-alternatives --install %{_bindir}/cdda2wav cdda2wav %{_bindir}/icedax 10 \
    --slave %_mandir/man1/cdda2wav.1%{_extension} cdda2wav.1%{_extension} %_mandir/man1/icedax.1%{_extension}

update-alternatives --install %{_bindir}/cdrecord cdrecord %{_bindir}/wodim 10 \
    --slave %_mandir/man1/cdrecord.1%{_extension} cdrecord.1%{_extension} %_mandir/man1/wodim.1%{_extension}
update-alternatives --install %{_bindir}/readcd readcd %{_bindir}/readom 10 \
    --slave %_mandir/man1/readcd.1%{_extension} readcd.1%{_extension} %_mandir/man1/readom.1%{_extension}

update-alternatives --install %{_bindir}/mkisofs mkisofs %{_bindir}/genisoimage 10 \
    --slave %_mandir/man1/mkisofs.1%{_extension} mkisofs.1%{_extension} %_mandir/man1/genisoimage.1%{_extension}
update-alternatives --install %{_bindir}/mkhybrid mkhybrid %{_bindir}/genisoimage 10 \
    --slave %_mandir/man1/mkhybrid.1%{_extension} mkhybrid.1%{_extension} %_mandir/man1/genisoimage.1%{_extension}

%files
%{_prefix}/local/bin/*
%{_prefix}/local/sbin/rscsi
%{_prefix}/local/lib/siconv
%{_prefix}/local/share/man/man1/*
%{_prefix}/local/share/man/man8/*
%{_sysconfdir}/default/cdrecord
%{_sysconfdir}/default/rscsi
%doc %{_prefix}/local/share/doc/mkisofs
%doc %{_prefix}/local/share/doc/libparanoia
%doc %{_prefix}/local/share/doc/rscsi
%doc %{_prefix}/local/share/doc/cdda2wav
%doc %{_prefix}/local/share/doc/cdrecord


%changelog
* Mon Dec 25 2017 Zen Subz <techars21 at gmail dot com> - 3.02a09-1pclos2017
- Built for PCLinuxOS
